#### LOAD config_file
args = commandArgs(TRUE)
if (length(args) > 0) {
  configFile_path <- args[1]
} else {
  cat("\n***WARNING: no ConfigFile was provided. Using default ConfigFile.\n")
}
config       <- yaml::yaml.load_file(configFile_path)
file         <- config$file
nparams      <- config$nparams
n_dim        <- config$n_dim
sim_data     <- config$sim_data
image_folder <- config$image_folder
n_outputs    <- config$n_outputs
repo         <- config$repo

#### Load external functions
source(paste0(repo,"UQtools4es.R"))
library(gbm)

#### Load data
reduced_train  <- readRDS(paste0(sim_data,"reduced_train.RDS"))
mypca          <- readRDS(paste0(sim_data,"mypca.RDS"))
data_to_validate <- readRDS(paste0(sim_data,"data_to_validate.RDS"))

#### BUILD surrogate
model_params_formula <- "~"
for (param in colnames(reduced_train[1,(n_outputs+1):ncol(reduced_train)]) ) {
	model_params_formula <- paste(model_params_formula, "+",param)
}
c_gbm   <- multiple_gbm(model_params_formula, reduced_train, n_outputs)

##### Compute relative error of the surrogate based on the training data
res <- surrogate_model(data_to_validate[,(n_dim+1):ncol(data_to_validate)],c_gbm, mypca, n_outputs,log_data=TRUE) # Evaluate surrogate using model parameters from data_to_validate
original <- data_to_validate[,1:n_dim]  
# Compute square error from PCA + Surrogate using validation data
norm_diff <- norm( as.matrix(data_to_validate[,1:n_dim] - res[,]) , type = "f")  
norm_data <- norm( as.matrix(data_to_validate[,1:n_dim])          , type = "f")  
rel_err <- 100 * norm_diff / norm_data 
print(paste(rel_err,"%"))


#### save data
saveRDS(c_gbm,  file = paste0(sim_data,"c_gbm.RDS"))
