#### LOAD config_file
args = commandArgs(TRUE)
if (length(args) > 0) {
  configFile_path <- args[1]
} else {
  cat("\n***WARNING: no ConfigFile was provided. Using default ConfigFile.\n")
}
config       <- yaml::yaml.load_file(configFile_path)
file         <- config$file
nparams      <- config$nparams
n_dim        <- config$n_dim
sim_data     <- config$sim_data
image_folder <- config$image_folder
n_outputs    <- config$n_outputs
repo         <- config$repo
nsims 	     <- config$nsims_sobol

param_names  <- config$cparam_names

print(param_names)
stop
#### Load external functions
source(paste0(repo,"UQtools4es.R"))
library(gbm)

#### Load data
reduced_train  <- readRDS(paste0(sim_data,"reduced_train.RDS"))
mypca          <- readRDS(paste0(sim_data,"mypca.RDS"))
data_to_validate <- readRDS(paste0(sim_data,"data_to_validate.RDS"))

#####  Generate Random Sobol sequence of model parameters to analyze sensitivity #####
lds <- runif.sobol(n = nsims, dimension = nparams, scrambling = 3)
param_names <- c("wsbio","wsbio2","wsbio2max","grazflux","wchld","wchldm","xremip","solgoc","caco3r","unass","unass2")
min_values <- c( 0, 25, 50,  500,   0,  0,0.01,  0,0.15, 0.1, 0.1)
max_values <- c(10,100,400,12000,0.05,0.1,0.15,0.5, 0.6, 0.5, 0.5)
new_value <- lds
for (j in 1:nparams){
    new_value[,j] = min_values[j] + lds[,j]*( max_values[j] - min_values[j] )
}
new_value <- as.data.frame(new_value)
colnames(new_value) <- param_names

##### Perform sensitivity analysis based on the "new_value"  ####
## Randomly split data
sobol_size <- floor(0.5 * nrow(new_value))
random_index <- sample(seq_len(nrow(new_value)), size = sobol_size)
X1 <- new_value[random_index,]
X2 <- new_value[-random_index,]

## ANALYSIS on the Principal Components

Sobol_global <- mulitple_sobol_onPC(surrogate_model_onPC,X1,X2,c_gbm)

barplot(t(as.matrix(Sobol_global[[1]])), main="First order Sobol indexes",
        xlab="Principal Components", col=rainbow(11),
        legend = colnames(Sobol_global[[1]]))

barplot(t(as.matrix(Sobol_global[[2]])), main="Total order Sobol indexes",
        xlab="Principal Components", col=rainbow(11),
        legend = colnames(Sobol_global[[1]]))

colSums(Sobol_global[[1]][1:4,])

Sobol_global2 <- mulitple_sobol_vjan(surrogate_model_onPC2,X1,X2, dim_output=n_outputs,c_gbm)


## ANALYSIS on the physical space

Sobol_global3 <- mulitple_sobol_vjan(surrogate_model,X1,X2, dim_output=n_dim, c_gbm, mypca, n_outputs=n_outputs,i=NULL,log_data=TRUE)

#### save data
saveRDS(c_gbm,  file = paste0(sim_data,"c_gbm.RDS"))
