#### LOAD config_file
args = commandArgs(TRUE)
if (length(args) > 0) {
  configFile_path <- args[1]
} else {
  cat("\n***WARNING: no ConfigFile was provided. Using default ConfigFile.\n")
}
config       <- yaml::yaml.load_file(configFile_path)
files         <- config$file
nparams      <- config$nparams
n_dim        <- config$n_dim
sim_data     <- config$sim_data
image_folder <- config$image_folder
n_outputs    <- config$n_outputs
repo         <- config$repo



#### Load data
all_out <- data.frame()
for (file in files) {
	out     <- load(file=file)
	all_out <- rbind(all_out,out)
}
data_var <- all_out[,(nparams+1):ncol(all_out)]
data <- cbind(data_var,all_out[,1:nparams])

## 80% of the sample size
smp_size <- floor(0.8 * nrow(data))

## set the seed to make your partition reproducible
set.seed(123)
train_ind <- sample(seq_len(nrow(data)), size = smp_size)

## split data
data_to_train <-data[train_ind,]
data_to_validate <-data[-train_ind,]

#### save data
saveRDS(data_to_validate,  file = paste0(sim_data,"data_to_validate.RDS"))
saveRDS(data_to_train,     file = paste0(sim_data,"data_to_train.RDS"))
